@@ -695,7 +695,7 @@ save_exif_ifd_tags(i_img *im, imtiff *tiff) {
       memcpy(user_comment, tiff->base + entry->offset, entry->size);
       /* the first 8 bytes indicate the encoding, make them into spaces
 	 for better presentation */
-      for (i = 0; i < 8; ++i) {
+      for (i = 0; i < entry->size && i < 8; ++i) {
 	if (user_comment[i] == '\0')
 	  user_comment[i] = ' ';
       }
@@ -936,7 +936,7 @@ tiff_load_ifd(imtiff *tiff, unsigned long offset) {
     entry->tag = tiff_get16(tiff, base);
     entry->type = tiff_get16(tiff, base+2);
     entry->count = tiff_get32(tiff, base+4);
-    if (entry->type >= 1 || entry->type <= ift_last) {
+    if (entry->type >= 1 && entry->type <= ift_last) {
       entry->item_size = type_sizes[entry->type];
       entry->size = entry->item_size * entry->count;
       if (entry->size / entry->item_size != entry->count) {
@@ -1552,7 +1552,7 @@ Tony Cook <tony@imager.perl.org>
 
 =head1 REVISION
 
-$Revision: 900 $
+$Revision: 984 $
 
 =cut
 */
